/// <reference types="react" />
import * as V from "@nexys/validation";
export interface InputProps<A> {
    onChange: (v: A | undefined) => void;
    value?: A;
    errors?: string[];
    disabled?: boolean;
    placeholder?: string;
}
export interface OptionSet<A> {
    id: A;
    name: string;
}
export interface WrapperProps {
    label?: string;
    info?: string;
    children: JSX.Element | JSX.Element[];
    errors?: string[];
}
/**
 * select props for dropdowns that return either a string or number (ie. enum)
 */
export declare type InputTypeString = "text" | "email" | "password";
/**
 * select props for dropdowns that return an option set
 */
export declare type InputType = InputTypeString | "number";
export interface SelectProps<A> extends InputProps<A> {
    options: OptionSet<A>[];
}
export interface SelectOptionSetProps<A> extends InputProps<OptionSet<A>> {
    options: OptionSet<A>[];
}
export declare enum FormType {
    Number = 0,
    Text = 1,
    Select = 2,
    SelectObject = 3,
    Switch = 4
}
export interface StructureViewUnit<A> {
    name: keyof A;
    label?: string;
    options?: {
        id: number;
        name: string;
    }[];
    render?: (a: A) => string;
}
export interface FormDef<A> {
    name: keyof A;
    label?: string;
    uiType: FormType;
    optional: boolean;
    options?: {
        id: number;
        name: string;
    }[];
}
export interface StructureUnit<A> extends StructureViewUnit<A> {
    uiType?: FormType;
}
export interface FormProps<A> {
    data: Partial<A>;
    structure: StructureUnit<A>[];
    errors?: {
        [k in keyof A]?: string[];
    };
    onSubmit: (data: Partial<A>) => Promise<void>;
}
export interface FormProps2<A> {
    formDef: FormDef<A>[];
    onSuccess: (v: A) => void;
    valueDefault?: Partial<A>;
    errors?: V.Type.ErrorOut | V.Type.Error;
    isLoading?: boolean;
}
export declare type ToggleProps<A> = Omit<FormProps<A>, "structure"> & {
    formDef: FormDef<A>[];
};
export declare type InputUnitProps<Id> = {
    type: FormType;
    options?: OptionSet<number | string>[];
} & InputProps<Id>;
